@@ -1,10 +1,10 @@
-"""
-    Creates the sceleton for new projects.
-    Similar to the template part of PasteScript, but uses Jinja templates.
+""" Creates the sceleton for new projects.
+
+Similar to the template part of PasteScript, but uses Jinja templates.
 
 
-    :copyright: 2013 by Kirill Klenov.
-    :license: BSD, see LICENSE for more details.
+:copyright: 2013 by Kirill Klenov.
+:license: BSD, see LICENSE for more details.
 
 """
 from os import getcwd, path as op
@@ -13,7 +13,7 @@ from os import getcwd, path as op
 # Module information
 # ==================
 
-__version__ = '0.3.0'
+__version__ = '0.4.0'
 __project__ = 'Starter'
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "BSD"
@@ -22,7 +22,7 @@ __license__ = "BSD"
 # Global configuration
 # ====================
 
-CFGFILE = '.starter.ini'
+CFGFILE = 'starter.ini'
 CURDIR = getcwd()
 BUILTIN_TMPLDIR = op.relpath(op.join(op.dirname(__file__), 'templates'))
-HOME_TMPLDIR_NAME = 'starter.d'
+HOME_TMPLDIR_NAME = '.starter'
